Basic Use — SciDB-Py 14.7.0 documentation

# Basic Use

The primary data structure in SciDB-Py is the `SciDBArray`. This object defines a NumPy array-like interface for SciDB arrays in Python. While `SciDBArray` syntax mimics NumPy, array operations are converted to SciDB queries which are executed by the database. Data are materialized to Python only when requested. A basic set of array subsetting, arithmetic and utility operations are defined by the package. Additionally, SciDB-Py provides several utilities for compising SciDB queries more explicitly.

- Introduction to SciDB arrays
- Loading the scidbpy package and connecting to SciDB
- Creating arrays
- Accessing array data
- Operations on SciDB array objects
- Comparing and Filtering Arrays
- The SciDB Query Interface
- Downloading SciDBArrays